@@ -26,4 +26,7 @@ class DataframeRenameCodeChunk(CodeChunk):
         if old_dataframe_name == new_dataframe_name:
             return []
 
-        return [f'{self.post_state.df_names[sheet_index]} = {old_dataframe_name}']
\ No newline at end of file
+        return [f'{self.post_state.df_names[sheet_index]} = {old_dataframe_name}']
+
+    def get_edited_sheet_indexes(self) -> List[int]:
+        return [self.get_param('sheet_index')]
\ No newline at end of file
