@@ -12,20 +12,22 @@ import time
 from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
-from mitosheet.user.location import is_in_google_colab, is_in_vs_code
 import traitlets as t
 from ipywidgets import DOMWidget
 
 from mitosheet._frontend import module_name, module_version
 from mitosheet.api import API
 from mitosheet.data_in_mito import DataTypeInMito
-from mitosheet.errors import MitoError, get_recent_traceback
-from mitosheet.mito_analytics import (log, log_event_processed,
-                                      log_recent_error, telemetry_turned_on)
+from mitosheet.errors import (MitoError, get_recent_traceback,
+                              make_execution_error)
 from mitosheet.saved_analyses import write_analysis
 from mitosheet.steps_manager import StepsManager
+from mitosheet.telemetry.telemetry_utils import (log, log_event_processed,
+                                                 telemetry_turned_on)
+from mitosheet.updates.replay_analysis import REPLAY_ANALYSIS_UPDATE
 from mitosheet.user import is_local_deployment, should_upgrade_mitosheet
 from mitosheet.user.db import get_user_field
+from mitosheet.user.location import is_in_google_colab, is_in_vs_code
 from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES,
                                     UJ_RECEIVED_TOURS, UJ_USER_EMAIL)
 from mitosheet.user.utils import is_excel_import_enabled, is_pro
@@ -36,18 +38,18 @@ class MitoWidget(DOMWidget):
         The MitoWidget holds all of the backend state for the Mito extension, and syncs
         the state with the frontend widget. 
     """
-    _model_name = t.Unicode('ExampleModel').tag(sync=True)
-    _model_module = t.Unicode(module_name).tag(sync=True)
-    _model_module_version = t.Unicode(module_version).tag(sync=True)
-    _view_name = t.Unicode('ExampleView').tag(sync=True)
-    _view_module = t.Unicode(module_name).tag(sync=True)
-    _view_module_version = t.Unicode(module_version).tag(sync=True)
+    _model_name = t.Unicode('ExampleModel').tag(sync=True) # type: ignore
+    _model_module = t.Unicode(module_name).tag(sync=True) # type: ignore
+    _model_module_version = t.Unicode(module_version).tag(sync=True) # type: ignore
+    _view_name = t.Unicode('ExampleView').tag(sync=True) # type: ignore
+    _view_module = t.Unicode(module_name).tag(sync=True) # type: ignore
+    _view_module_version = t.Unicode(module_version).tag(sync=True) # type: ignore
 
-    sheet_data_json = t.Unicode('').tag(sync=True)
-    analysis_data_json = t.Unicode('').tag(sync=True)
-    user_profile_json = t.Unicode('').tag(sync=True)
+    sheet_data_json = t.Unicode('').tag(sync=True) # type: ignore
+    analysis_data_json = t.Unicode('').tag(sync=True) # type: ignore
+    user_profile_json = t.Unicode('').tag(sync=True) # type: ignore
     
-    def __init__(self, *args: List[Union[pd.DataFrame, str]]):
+    def __init__(self, *args: List[Union[pd.DataFrame, str]], analysis_to_replay: str=None):
         """
         Takes a list of dataframes and strings that are paths to CSV files
         passed through *args.
@@ -56,7 +58,7 @@ class MitoWidget(DOMWidget):
         super(MitoWidget, self).__init__()
             
         # Set up the state container to hold private widget state
-        self.steps_manager = StepsManager(args)
+        self.steps_manager = StepsManager(args, analysis_to_replay=analysis_to_replay)
 
         # Set up message handler
         self.on_msg(self.receive_message)
@@ -142,11 +144,19 @@ class MitoWidget(DOMWidget):
         - Name of an existing analysis
         """
 
-        self.steps_manager.handle_update_event(event)
-
-        # Update all state variables
-        self.update_shared_state_variables()
+        try:
+            self.steps_manager.handle_update_event(event)
 
+            # Update all state variables
+            self.update_shared_state_variables()
+        except:
+            # We handle the case of replaying the analysis specially, because we don't
+            # want to display the error modal - we want to display something specific
+            # in this case. Note that we include the updating of shared state variables
+            # in the try catch, as this is sometimes where errors occur
+            if event["type"] == REPLAY_ANALYSIS_UPDATE['event_type']:
+                raise make_execution_error(error_modal=False)
+            raise
         # Also, write the analysis to a file!
         write_analysis(self.steps_manager)
 
@@ -196,8 +206,6 @@ class MitoWidget(DOMWidget):
 
             return True
         except MitoError as e:
-            print(get_recent_traceback())
-            print(e)
             
             # Log processing this event failed
             log_event_processed(event, self.steps_manager, failed=True, mito_error=e, start_time=start_time)
@@ -225,7 +233,6 @@ class MitoWidget(DOMWidget):
             # Report it to the user, and then return
             self.send(response)
         except:
-            print(get_recent_traceback())
             # We log that processing failed, but have no edit error
             log_event_processed(event, self.steps_manager, failed=True, start_time=start_time)
             # Report it to the user, and then return
@@ -242,7 +249,8 @@ class MitoWidget(DOMWidget):
 
 def sheet(
         *args: Any,
-        view_df: bool=False # We use this param to log if the mitosheet.sheet call is created from the df output button
+        analysis_to_replay: str=None, # This is the parameter that tracks the analysis that you want to replay (NOTE: requires a frontend to be replayed!)
+        view_df: bool=False, # We use this param to log if the mitosheet.sheet call is created from the df output button,
         # NOTE: if you add named variables to this function, make sure argument parsing on the front-end still
         # works by updating the getArgsFromCellContent function.
     ) -> MitoWidget:
@@ -267,12 +275,12 @@ def sheet(
     # vs code or google collab (these conditions are more secure than
     # the conditons for checking if we're in JLab or JNotebook).
     if is_in_vs_code() or is_in_google_colab():
-        log_recent_error('mitosheet_sheet_call_location_failed')
+        log('mitosheet_sheet_call_location_failed', failed=True)
         raise Exception("The mitosheet currently only works in JupyterLab.\n\nTo see instructions on getting Mitosheet running in JupyterLab, find install instructions here: https://docs.trymito.io/getting-started/installing-mito")
 
     try:
         # We pass in the dataframes directly to the widget
-        widget = MitoWidget(*args) 
+        widget = MitoWidget(*args, analysis_to_replay=analysis_to_replay) 
 
         # Log they have personal data in the tool if they passed a dataframe
         # that is not tutorial data or sample data from import docs
@@ -280,25 +288,21 @@ def sheet(
             log('used_personal_data') 
 
     except:
-        log_recent_error('mitosheet_sheet_call_failed')
+        log('mitosheet_sheet_call_failed', failed=True)
         raise
 
     # Then, we log that the call was successful, along with all of it's params
     log(
         'mitosheet_sheet_call',
-        dict(
-            **{
-                # NOTE: analysis name is the UUID that mito saves the analysis under
-                'steps_manager_analysis_name': widget.steps_manager.analysis_name,
-            },
-            **{
-                'param_num_args': len(args),
-                'params_num_str_args': len([arg for arg in args if isinstance(arg, str)]),
-                'params_num_df_args': len([arg for arg in args if isinstance(arg, pd.DataFrame)]),
-                'params_df_index_type': [str(type(arg.index)) for arg in args if isinstance(arg, pd.DataFrame)],
-                'params_view_df': view_df
-            }
-        )
+        {
+            # NOTE: analysis name is the UUID that mito saves the analysis under
+            'steps_manager_analysis_name': widget.steps_manager.analysis_name,
+            'num_args': len(args),
+            'num_str_args': len([arg for arg in args if isinstance(arg, str)]),
+            'num_df_args': len([arg for arg in args if isinstance(arg, pd.DataFrame)]),
+            'df_index_type': [str(type(arg.index)) for arg in args if isinstance(arg, pd.DataFrame)],
+            'view_df': view_df
+        }
     )
 
     return widget
