@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Contains all functions that can be used in a sheet that operate on
 numbers.
@@ -19,14 +18,13 @@ from typing import Tuple
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types import NUMBER_SERIES
-from mitosheet.sheet_functions.types.decorators import filter_nans, convert_args_to_series_type, convert_arg_to_series_type, handle_sheet_function_errors
+from mitosheet.sheet_functions.types.decorators import fill_nans, filter_nans, convert_args_to_series_type, convert_arg_to_series_type, handle_sheet_function_errors
 from mitosheet.sheet_functions.sheet_function_utils import try_extend_series_to_index, fill_series_with_one_index, fill_series_with_one_index
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -35,6 +33,7 @@ def ABS(series: pd.Series) -> pd.Series:
     {
         "function": "ABS",
         "description": "Returns the absolute value of the passed number or series.",
+        "search_terms": ["abs", "absolute value"],
         "examples": [
             "ABS(-1.3)",
             "ABS(A)"
@@ -52,12 +51,13 @@ def ABS(series: pd.Series) -> pd.Series:
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', np.NaN))
+@convert_args_to_series_type('float', 'skip', ('default', np.NaN))
 def AVG(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "AVG",
         "description": "Returns the numerical mean value of the passed numbers and series.",
+        "search_terms": ["avg", "average", "mean"],
         "examples": [
             "AVG(1, 2)",
             "AVG(A, B)",
@@ -85,13 +85,13 @@ def AVG(*argv: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -100,6 +100,7 @@ def CORR(s1: pd.Series, s2: pd.Series) -> pd.Series:
     {
         "function": "CORR",
         "description": "Computes the correlation between two series, excluding missing values.",
+        "search_terms": ["corr", "correlation", "r^2"],
         "examples": [
             "=CORR(A, B)",
             "=CORR(B, A)"
@@ -121,11 +122,67 @@ def CORR(s1: pd.Series, s2: pd.Series) -> pd.Series:
         index=s1.index
     )
 
+@handle_sheet_function_errors
+@filter_nans
+@convert_arg_to_series_type(
+    0,
+    'float',
+    'error',
+    ('default', np.NaN)
+)
+def FLOAT(series: pd.Series) -> pd.Series:
+    """
+    {
+        "function": "FLOAT",
+        "description": "Converts a string series to a float series. Any values that fail to convert will return NaN.",
+        "search_terms": ["number", "to number"],
+        "examples": [
+            "=FLOAT(Prices_string)",
+            "=FLOAT('123.123')"
+        ],
+        "syntax": "FLOAT(string_series)",
+        "syntax_elements": [{
+                "element": "string_series",
+                "description": "The series or string to convert to a float."
+            }
+        ]
+    }
+    """
+    return series
+
+@handle_sheet_function_errors
+@fill_nans(0, 0)
+@convert_arg_to_series_type(
+    0,
+    'int',
+    'error',
+    ('default', 0)
+)
+def INT(series: pd.Series) -> pd.Series:
+    """
+    {
+        "function": "INT",
+        "description": "Converts a string series to a int series. Any values that fail to convert will return 0.",
+        "search_terms": ["number", "to integer"],
+        "examples": [
+            "=INT(Prices_string)",
+            "=INT('123')"
+        ],
+        "syntax": "INT(string_series)",
+        "syntax_elements": [{
+                "element": "string_series",
+                "description": "The series or string to convert to a int."
+            }
+        ]
+    }
+    """
+    return series
+
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -135,6 +192,7 @@ def KURT(series: pd.Series) -> pd.Series:
     {
         "function": "KURT",
         "description": "Computes the unbiased kurtosis, a measure of tailedness, of a series, excluding missing values.",
+        "search_terms": ["kurtosis"],
         "examples": [
             "=KURT(A)",
             "=KURT(A * B)"
@@ -157,12 +215,13 @@ def KURT(series: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @filter_nans
 # NOTE: we set the default to -inf, so that we ignore values that fail to convert
-@convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', float("-inf")))
+@convert_args_to_series_type('float', 'skip', ('default', float("-inf")))
 def MAX(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "MAX",
         "description": "Returns the maximum value among the passed arguments.",
+        "search_terms": ["max", "maximum", "minimum"],
         "examples": [
             "MAX(10, 11)",
             "MAX(Old_Data, New_Data)"
@@ -187,12 +246,13 @@ def MAX(*argv: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @filter_nans
 # NOTE: we set the default to inf, so that we ignore values that fail to convert
-@convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', float("inf")))
+@convert_args_to_series_type('float', 'skip', ('default', float("inf")))
 def MIN(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "MIN",
         "description": "Returns the minimum value among the passed arguments.",
+        "search_terms": ["min", "minimum", "maximum"],
         "examples": [
             "MIN(10, 11)",
             "MIN(Old_Data, New_Data)"
@@ -216,12 +276,13 @@ def MIN(*argv: pd.Series) -> pd.Series:
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', 1))
+@convert_args_to_series_type('float', 'skip', ('default', 1))
 def MULTIPLY(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "MULTIPLY",
         "description": "Returns the product of two numbers.",
+        "search_terms": ["mulitply", "product"],
         "examples": [
             "MULTIPLY(2,3)",
             "MULTIPLY(A,3)"
@@ -248,13 +309,13 @@ def MULTIPLY(*argv: pd.Series) -> pd.Series:
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
-    NUMBER_SERIES,
+    'float',
     'skip',
     ('default', 1)
 )
@@ -263,6 +324,7 @@ def POWER(series, power):
     {
         "function": "POWER",
         "description": "The POWER function can be used to raise a number to a given power.",
+        "search_terms": ["power", "raise", "exponent", "square", "cube"],
         "examples": [
             "POWER(4, 1/2)",
             "POWER(Dose, 2)"
@@ -287,13 +349,13 @@ def POWER(series, power):
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', 2),
     optional=True
@@ -303,6 +365,7 @@ def ROUND(series, decimals=None):
     {
         "function": "ROUND",
         "description": "Rounds a number to a given number of decimals.",
+        "search_terms": ["round", "decimal", "integer"],
         "examples": [
             "ROUND(1.3)",
             "ROUND(A, 2)"
@@ -335,7 +398,7 @@ def ROUND(series, decimals=None):
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -345,6 +408,7 @@ def SKEW(series: pd.Series) -> pd.Series:
     {
         "function": "SKEW",
         "description": "Computes the skew of a series, excluding missing values.",
+        "search_terms": [],
         "examples": [
             "=SKEW(A)",
             "=SKEW(A * B)"
@@ -366,12 +430,13 @@ def SKEW(series: pd.Series) -> pd.Series:
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', 0))
+@convert_args_to_series_type('float', 'skip', ('default', 0))
 def SUM(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "SUM",
         "description": "Returns the sum of the given numbers and series.",
+        "search_terms": ["add"],
         "examples": [
             "SUM(10, 11)",
             "SUM(A, B, D, F)",
@@ -398,7 +463,7 @@ def SUM(*argv: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -408,6 +473,7 @@ def STDEV(series: pd.Series) -> pd.Series:
     {
         "function": "STDEV",
         "description": "Computes the standard deviation of a series, excluding missing values.",
+        "search_terms": ["standard", "deviation", "standard", "distribution"],
         "examples": [
             "=STDEV(A)",
             "=STDEV(A * B)"
@@ -432,7 +498,7 @@ def STDEV(series: pd.Series) -> pd.Series:
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -441,6 +507,7 @@ def VALUE(series: pd.Series) -> pd.Series:
     {
         "function": "VALUE",
         "description": "Converts a string series to a number series. Any values that fail to convert will return an NaN.",
+        "search_terms": ["number", "to number", "dtype", "convert", "parse"],
         "examples": [
             "=VALUE(A)",
             "=VALUE('123')"
@@ -460,7 +527,7 @@ def VALUE(series: pd.Series) -> pd.Series:
 @filter_nans
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -469,6 +536,7 @@ def EXP(series: pd.Series) -> pd.Series:
     {
         "function": "EXP",
         "description": "Returns e, the base of the natural logarithm, raised to the power of passed series.",
+        "search_terms": ["exp", "exponent", "log", "natural log"],
         "examples": [
             "=EXP(data)",
             "=EXP(A)"
@@ -487,7 +555,7 @@ def EXP(series: pd.Series) -> pd.Series:
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
-    NUMBER_SERIES,
+    'float',
     'error',
     ('default', np.NaN)
 )
@@ -497,6 +565,7 @@ def VAR(series: pd.Series) -> pd.Series:
     {
         "function": "VAR",
         "description": "Computes the variance of a series, excluding missing values.",
+        "search_terms": ["variance"],
         "examples": [
             "=VAR(A)",
             "=VAR(A - B)"
@@ -520,6 +589,8 @@ NUMBER_FUNCTIONS = {
     'ABS': ABS,
     'AVG': AVG,
     'CORR': CORR,
+    'FLOAT': FLOAT,
+    'INT': INT,
     'EXP': EXP,
     'KURT': KURT,
     'MAX': MAX,
