@@ -1,3 +1,9 @@
+#!/usr/bin/env python
+# coding: utf-8
+
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
+
 """
 NOTE: DO NOT CHANGE THIS FILE. THESE ARE DEPRECATED UTILS
 THAT CANNOT CHANGE AND SO SHOULD NEVER BE CHANGED.
@@ -5,15 +11,17 @@ THAT CANNOT CHANGE AND SO SHOULD NEVER BE CHANGED.
 
 import numbers
 import re
-from typing import Any, Dict, List
-from mitosheet.mito_analytics import log
+from typing import Any, Callable, Dict, List
+from mitosheet.telemetry.telemetry_utils import log
 
 import pandas as pd
 
 import warnings
 import functools
 
-def deprecated(func):
+from mitosheet.types import ColumnHeader
+
+def deprecated(func: Callable) -> Callable:
     """
     This is a decorator which can be used to mark functions
     as deprecated. It will result in a warning being emitted
@@ -91,7 +99,7 @@ def make_valid_header(column_header: Any) -> str:
 make_valid_header_external = deprecated(make_valid_header)
 
 
-def is_valid_header(column_header: Any) -> bool:
+def is_valid_header(column_header: ColumnHeader) -> bool:
     """
     A header is valid if it is a string that is made up of all word characters,
     with at least one non numeric char, and has at least one char.
@@ -122,7 +130,7 @@ def get_invalid_headers(df: pd.DataFrame) -> List[Any]:
         if not is_valid_header(header)
     ]
 
-def get_header_renames(column_headers) -> Dict[Any, str]:
+def get_header_renames(column_headers: List[ColumnHeader]) -> Dict[Any, str]:
     """
     Given a list of column headers, returns a mapping from old, invalid headers to
     new, valid headers. Empty if no renames are necessary.
