@@ -6,11 +6,14 @@
 from copy import deepcopy
 from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.column_steps.delete_column_code_chunk import DeleteColumnsCodeChunk
 
 from mitosheet.errors import make_invalid_column_delete_error
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.evaluation_graph_utils import create_column_evaluation_graph, topological_sort_columns
+from mitosheet.step_performers.utils import get_param
 from mitosheet.transpiler.transpile_utils import column_header_list_to_transpiled_code
 from mitosheet.types import ColumnID
 
@@ -28,29 +31,17 @@ class DeleteColumnStepPerformer(StepPerformer):
     def step_type(cls) -> str:
         return 'delete_column'
 
-    @classmethod
-    def step_display_name(cls) -> str:
-        return 'Deleted Column(s)'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'delete_column_edit'
-
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         return params
 
     @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        sheet_index: int,
-        column_ids: List[ColumnID],
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        sheet_index: int = get_param(params, 'sheet_index')
+        column_ids: List[ColumnID] = get_param(params, 'column_ids')
 
         # Make a post state, that is a deep copy
-        post_state = deepcopy(prev_state)
+        post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
 
         # Actually delete the columns and update state
         post_state, pandas_processing_time = delete_column_ids(post_state, sheet_index, column_ids)
@@ -62,35 +53,16 @@ class DeleteColumnStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        sheet_index: int,
-        column_ids: List[ColumnID]
-    ) -> List[str]:
-
-        df_name = post_state.df_names[sheet_index]
-        column_headers_list_string = column_header_list_to_transpiled_code(
-            [prev_state.column_ids.get_column_header_by_id(sheet_index, column_id) for column_id in column_ids]
-        )
-
-        return [f'{df_name}.drop({column_headers_list_string}, axis=1, inplace=True)']
-    
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        sheet_index: int,
-        column_ids: List[ColumnID],
-        df_names=None,
-        **params
-    ) -> str:
-        formated_column_ids = (', '.join(column_ids))
-        if df_names is not None:
-            df_name = df_names[sheet_index]
-            return f'Deleted column{"s" if len(column_ids) > 1 else ""} {formated_column_ids} from {df_name}'
-        return f'Deleted column{"s" if len(column_ids) > 1 else ""} {formated_column_ids}'
+    ) -> List[CodeChunk]:
+        return [
+            DeleteColumnsCodeChunk(prev_state, post_state, params, execution_data)
+        ]
 
     @classmethod
     def get_modified_dataframe_indexes( # type: ignore
@@ -107,6 +79,11 @@ def delete_column_ids(
     column_ids: List[ColumnID],
 ) -> Tuple[State, float]:
 
+
+    # First, we check that we can delete these columns, and error if we cannot
+    if not set(column_ids).issubset(set(state.column_ids.get_column_ids_map(sheet_index).keys())):
+        raise make_invalid_column_delete_error(column_ids)
+
     column_evaluation_graph = create_column_evaluation_graph(state, sheet_index)
 
     # Put the columns in a topological sorting so we delete columns that reference
@@ -144,7 +121,7 @@ def _delete_column_id(
     
     column_evaluation_graph = create_column_evaluation_graph(state, sheet_index)
     column_header = state.column_ids.get_column_header_by_id(sheet_index, column_id)
-    
+
     # Return False if there are any columns that currently rely on this column, 
     # so we can display an error message with all of the un-deletable columns.
     if len(column_evaluation_graph[column_id]) > 0:
