@@ -1,20 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Rolls back/forward to a specific step, by index
 """
 
-from typing import TYPE_CHECKING, Any
-
-
-if TYPE_CHECKING:
-    from mitosheet.steps_manager import StepsManager
-else:
-    StepsManager = Any
+from mitosheet.types import StepsManagerType
 
 
 CHECKOUT_STEP_BY_IDX_UPDATE_EVENT = 'checkout_step_by_idx_update'
@@ -23,12 +16,16 @@ CHECKOUT_STEP_BY_IDX_UPDATE_PARAMS = [
 ]
 
 def execute_checkout_step_by_idx_update(
-        steps_manager: StepsManager,
+        steps_manager: StepsManagerType,
         step_idx: int
     ) -> None:
     """
     Checks out a specific step by index
     """
+    # If the new step index is -1, go to the end of the list!
+    if step_idx == -1:
+        step_idx = len(steps_manager.steps) - 1
+
     steps_manager.curr_step_idx = step_idx
 
 CHECKOUT_STEP_BY_IDX_UPDATE = {
